import 'package:flutter/material.dart';
import 'package:rothko_mobile/cache.dart';
import 'package:rothko_mobile/rothko_system/utilities/colors.dart';

class MobileTabs extends StatefulWidget {
  final String? tabOne, tabTwo, tabThree;
  final Widget? tabOneView, tabTwoView, tabThreeView;
  final TabController? tabController;
  final int? length;

  MobileTabs({
    this.length,
    this.tabOne,
    this.tabThree,
    this.tabTwo,
    this.tabOneView,
    this.tabTwoView,
    this.tabThreeView,
    this.tabController,
  });
  @override
  _MobileTabsState createState() => _MobileTabsState();
}

class _MobileTabsState extends State<MobileTabs>
    with SingleTickerProviderStateMixin {
  TabController? _tabController;
  int _currentIndex = 0;
  @override
  void initState() {
    super.initState();
    _tabController =
        new TabController(vsync: this, length: 3, initialIndex: _currentIndex);
    super.initState();
  }

  @override
  void dispose() {
    _tabController!.dispose();
    super.dispose();
  }

  Widget build(BuildContext context) {
    return Scaffold(
      appBar: PreferredSize(
        preferredSize: Size(MediaQuery.of(context).size.width, 56),
        child: Padding(
          padding: EdgeInsets.symmetric(horizontal: 8.0),
          child: Container(
            decoration: BoxDecoration(
                color: RothkoCache.getTheme!(context) == ThemeMode.light
                    ? kPrimaryBase
                    : kPrimaryLighten0,
                borderRadius: BorderRadius.circular(8.0)),
            child: TabBar(
              controller: widget.tabController ?? _tabController,
              labelColor: RothkoCache.getTheme!(context) == ThemeMode.light
                  ? kLightNeutralLighten0
                  : kPrimaryBase,
              unselectedLabelColor:
                  RothkoCache.getTheme!(context) == ThemeMode.light
                      ? kPrimaryLighten3
                      : kDarkNeutralLighten4,
              indicatorSize: TabBarIndicatorSize.tab,
              indicatorColor: RothkoCache.getTheme!(context) == ThemeMode.light
                  ? kPrimaryLighten0
                  : kPrimaryBase,
              tabs: [
                Tab(
                  child: Text(
                    widget.tabOne ?? 'tab 1',
                    style: TextStyle(
                        fontFamily: 'Proxima Nova',
                        fontWeight: FontWeight.w700,
                        fontSize: 14.0),
                  ),
                ),
                Tab(
                  child: Text(
                    widget.tabTwo ?? 'tab 2',
                    style: TextStyle(
                        fontFamily: 'Proxima Nova',
                        fontWeight: FontWeight.w700,
                        fontSize: 14.0),
                  ),
                ),
                Tab(
                  child: Text(
                    widget.tabThree ?? 'tab 3',
                    style: TextStyle(
                        fontFamily: 'Proxima Nova',
                        fontWeight: FontWeight.w700,
                        fontSize: 14.0),
                  ),
                )
              ],
            ),
          ),
        ),
      ),
      body: TabBarView(
        children: [
          widget.tabOneView ??
              Container(
                child: Center(
                    child:
                        Text(' You should replace tabOneView with a widget')),
              ),
          widget.tabTwoView ??
              Container(
                child: Center(
                    child:
                        Text(' You should replace tabTwoView with a widget')),
              ),
          widget.tabThreeView ??
              Container(
                child: Center(
                    child:
                        Text(' You should replace tabThreeView with a widget')),
              ),
        ],
        controller: widget.tabController ?? _tabController,
      ),
    );
  }
}
